@@ -53,6 +53,9 @@ class PModeTestCase( unittest.TestCase ):
     def test_1100(self):
         self.run_test('1100')
 
+    def test_1101(self):
+        self.run_test('1101')
+
     def test_1102(self):
         self.run_test('1102')
 
