@@ -897,6 +897,10 @@ class CPPA3TestCase( unittest.TestCase ):
     def test_1534(self):
         self.assertRaises(cppa3.unify.UnificationException, self.do_unification, '1534')
 
+    # Bundling feature as referenced element
+    def test_1535(self):
+        self.do_unification('1535')
+
     # Scope ?
 
     # Split / Join / Compress
@@ -952,6 +956,80 @@ class CPPA3TestCase( unittest.TestCase ):
     def test_1611(self):
         self.do_unification('1611', handle_defaults=True)
 
+    # SuperAnnuation
+    # As defined in DATA AND PAYMENT STANDARDS
+    # MESSAGE ORCHESTRATION AND PROFILES
+    # https://www.ato.gov.au/uploadedFiles/Content/SPR/downloads/SPR26583msgorchest.pdf
+    # For rollover business process, source:
+    # https://www.ato.gov.au/uploadedFiles/Content/SPR/downloads/spr00335171_Rollover_Message_Implementation.pdf
+
+    # Ultra Light, Push
+    def test_1700(self):
+        self.do_unification('1700')
+
+    # Ultra Light, Push, multihop
+    def test_1701(self):
+        self.do_unification('1701')
+
+    # Light, Push
+    def test_1710(self):
+        self.do_unification('1710')
+
+    # Light, Pull
+    def test_1711(self):
+        self.do_unification('1711')
+
+    # Light, Push, multihop
+    def test_1715(self):
+        self.do_unification('1715')
+
+    # No test for Light, Pull, multihop
+    # because AS4 intermediaries don't pull from endpoints
+
+
+    # High end, Push
+    def test_1730(self):
+        self.do_unification('1730')
+
+    # High end, Push/PKI
+    def test_1731(self):
+        self.do_unification('1731')
+
+    # High end, Pull
+    def test_1732(self):
+        self.do_unification('1732')
+
+    # High end, Pull/PKI
+    def test_1733(self):
+        self.do_unification('1733')
+
+    # High end, Push, multihop
+    def test_1735(self):
+        self.do_unification('1735')
+
+    # High end, Push/PKI, multihop
+    def test_1736(self):
+        self.do_unification('1736')
+
+
+
+    # Large volume profile, Push PKI
+    def test_1741(self):
+        self.do_unification('1741')
+
+    # Large volume profile, Push PKI, more defaults
+    def test_1742(self):
+        self.do_unification('1742', handle_defaults=True)
+
+    # Large volume profile, Push PKI, channel features
+    def test_1743(self):
+        self.do_unification('1743', handle_defaults=True)
+
+    # Large volume profile, Push PKI, channel features, multihop
+    def test_1744(self):
+        self.do_unification('1744', handle_defaults=True)
+
+
     # 1900 SAML Conformance Clause
 
     # One IDP on both sides, matching
